@@ -1,4 +1,5 @@
-
+## File Name: mice.impute.2l.binary.R
+## File Version: 0.14
 
 
 mice.impute.2l.binary <- function(y, ry, x, type, intercept=TRUE,
@@ -6,9 +7,9 @@ mice.impute.2l.binary <- function(y, ry, x, type, intercept=TRUE,
                                   random.effects.shrinkage=1E-6,
                                   glmer.warnings=TRUE, 
 								  blme_use = FALSE , blme_args = NULL , 
-                                  ...){
-
-	imp <- mice.impute.2l.lmer(y=y, ry=ry, x=x, type=type, 
+                                  ...)
+{
+	imp <- mice_impute_2l_lmer(y=y, ry=ry, x=x, type=type, 
 				intercept=intercept, groupcenter.slope=groupcenter.slope, 
 				draw.fixed=draw.fixed,
 				random.effects.shrinkage=random.effects.shrinkage,
