@@ -1,9 +1,7 @@
 ## File Name: mice.impute.pmm6.R
-## File Version: 0.11
-
-mice.impute.pmm6 <- function (y, ry, x, donors=3 , noise = 10^5 , ridge = 10^(-5) , ...)
-{
-	x <- cbind(1, as.matrix(x))
+## File Version: 0.12
+mice.impute.pmm6 <- function (y, ry, x, donors=3 , noise = 10^5 , ridge = 10^(-5) , ...){
+    x <- cbind(1, as.matrix(x))
 	# dummy response indicator 
 	ry01 <- 1*ry
 	# sample regression coefficients
@@ -17,5 +15,5 @@ mice.impute.pmm6 <- function (y, ry, x, donors=3 , noise = 10^5 , ridge = 10^(-5
 	imp <- .Call("ma_pmm6_C", 
 				y_=y ,  ry01_=ry01 ,  x_=x,  ridge_=ridge ,  coefu_=coefu ,  donorsample_=donorsample	,
 				PACKAGE = "miceadds")	
-	return(imp)
-}
+    return(imp)
+	}
